@@ -480,6 +480,8 @@ func (c *Client) SyncMainDataCtx(ctx context.Context, rid int64) (*MainData, err
 		return nil, errors.Wrap(err, "could not get main data")
 	}
 
+	defer resp.Body.Close()
+
 	var info MainData
 	if err := json.NewDecoder(resp.Body).Decode(&info); err != nil {
 		return nil, errors.Wrap(err, "could not unmarshal body")
@@ -834,6 +836,51 @@ func (c *Client) GetFilesInformationCtx(ctx context.Context, hash string) (*Torr
 	return &info, nil
 }
 
+// SetFilePriority Set file priority
+func (c *Client) SetFilePriority(hash string, IDs string, priority int) (error) {
+	return c.SetFilePriorityCtx(context.Background(), hash, IDs, priority)
+}
+
+// SetFilePriorityCtx Set file priority
+func (c *Client) SetFilePriorityCtx(ctx context.Context, hash string, IDs string, priority int) (error) {
+	opts := map[string]string{
+		"hash": 	hash,
+		"id": 		IDs,
+		"priority": strconv.Itoa(priority),
+	}
+
+	resp, err := c.postCtx(ctx, "torrents/filePrio", opts)
+	if err != nil {
+		return errors.Wrap(err, "could not set file priority")
+	}
+
+	defer resp.Body.Close()
+
+	/*
+		HTTP Status Code 	Scenario
+		400		Priority is invalid
+		400 	At least one file id is not a valid integer
+		404 	Torrent hash was not found
+		409 	Torrent metadata hasn't downloaded yet
+		409 	At least one file id was not found
+		200 	All other scenarios
+	*/
+	switch resp.StatusCode {
+	case http.StatusBadRequest:
+		return errors.New("Priority is invalid")
+	case http.StatusNotFound:
+		return errors.New("torrent %s not found", hash)
+	case http.StatusConflict:
+		return errors.New("At least one file id was not found")
+	case http.StatusOK:
+		return nil
+	default:
+		return errors.New("could set file priority for torrent: %s unexpected status: %d", hash, resp.StatusCode)
+	}
+
+	return nil
+}
+
 func (c *Client) ExportTorrent(hash string) ([]byte, error) {
 	return c.ExportTorrentCtx(context.Background(), hash)
 }
@@ -1055,6 +1102,40 @@ func (c *Client) EditTrackerCtx(ctx context.Context, hash string, old, new strin
 	}
 }
 
+// AddTrackers add trackers of torrent
+func (c *Client) AddTrackers(hash string, urls string) error {
+	return c.AddTrackersCtx(context.Background(), hash, urls)
+}
+
+// AddTrackersCtx add trackers of torrent
+func (c *Client) AddTrackersCtx(ctx context.Context, hash string, urls string) error {
+	opts := map[string]string{
+		"hash": hash,
+		"urls": urls,
+	}
+	
+	resp, err := c.postCtx(ctx, "torrents/addTrackers", opts)
+	if err != nil {
+		return errors.Wrap(err, "could not edit tracker for torrent: %s", hash)
+	}
+
+	defer resp.Body.Close()
+
+	/*
+		HTTP Status Code 	Scenario
+		404 	Torrent hash was not found
+		200 	All other scenarios
+	*/
+	switch resp.StatusCode {
+	case http.StatusNotFound:
+		return errors.New("torrent %s not found", hash)
+	case http.StatusOK:
+		return nil
+	default:
+		return errors.New("could not add trackers for torrent: %s unexpected status: %d", hash, resp.StatusCode)
+	}
+}
+
 // SetPreferencesQueueingEnabled enable/disable torrent queueing
 func (c *Client) SetPreferencesQueueingEnabled(enabled bool) error {
 	return c.SetPreferences(map[string]interface{}{"queueing_enabled": enabled})
@@ -1222,27 +1303,81 @@ func (c *Client) ToggleFirstLastPiecePrioCtx(ctx context.Context, hashes []strin
 	return nil
 }
 
-// SetTorrentUploadLimit set upload limit for torrent specified by hash
-func (c *Client) SetTorrentUploadLimit(hash string, limit int64) error {
-	return c.SetTorrentUploadLimitCtx(context.Background(), hash, limit)
+// SetTorrentDownloadLimit set download limit for torrents specified by hashes
+func (c *Client) SetTorrentDownloadLimit(hashes []string, limit int64) error {
+	return c.SetTorrentDownloadLimitCtx(context.Background(), hashes, limit)
 }
 
-// SetTorrentUploadLimitCtx set upload limit for torrent specified by hash
-func (c *Client) SetTorrentUploadLimitCtx(ctx context.Context, hash string, limit int64) error {
+// SetTorrentDownloadLimitCtx set download limit for torrents specified by hashes
+func (c *Client) SetTorrentDownloadLimitCtx(ctx context.Context, hashes []string, limit int64) error {
 	opts := map[string]string{
-		"hashes": hash,
+		"hashes": strings.Join(hashes, "|"),
 		"limit":  strconv.FormatInt(limit, 10),
 	}
 
-	resp, err := c.postCtx(ctx, "torrents/setUploadLimit", opts)
+	resp, err := c.postCtx(ctx, "torrents/setDownloadLimit", opts)
 	if err != nil {
-		return errors.Wrap(err, "could not set upload limit torrent: %v", hash)
+		return errors.Wrap(err, "could not set download limit for torrents: %v", hashes)
 	}
 
 	defer resp.Body.Close()
 
 	if resp.StatusCode != http.StatusOK {
-		return errors.New("could not set upload limit torrent: %v unexpected status: %v", hash, resp.StatusCode)
+		return errors.New("could not set download limit for torrents: %v unexpected status: %v", hashes, resp.StatusCode)
+	}
+
+	return nil
+}
+
+// SetTorrentShareLimit set share limits for torrents specified by hashes
+func (c *Client) SetTorrentShareLimit(hashes []string, ratioLimit float64, seedingTimeLimit int64, inactiveSeedingTimeLimit int64) error {
+	return c.SetTorrentShareLimitCtx(context.Background(), hashes, ratioLimit, seedingTimeLimit, inactiveSeedingTimeLimit)
+}
+
+// SetTorrentShareLimitCtx set share limits for torrents specified by hashes
+func (c *Client) SetTorrentShareLimitCtx(ctx context.Context, hashes []string, ratioLimit float64, seedingTimeLimit int64, inactiveSeedingTimeLimit int64) error {
+	opts := map[string]string{
+		"hashes":                   strings.Join(hashes, "|"),
+		"ratioLimit":               strconv.FormatFloat(ratioLimit, 'f', 2, 64),
+		"seedingTimeLimit":         strconv.FormatInt(seedingTimeLimit, 10),
+		"inactiveSeedingTimeLimit": strconv.FormatInt(inactiveSeedingTimeLimit, 10),
+	}
+
+	resp, err := c.postCtx(ctx, "torrents/setShareLimits", opts)
+	if err != nil {
+		return errors.Wrap(err, "could not set share limits for torrents: %v", hashes)
+	}
+
+	defer resp.Body.Close()
+
+	if resp.StatusCode != http.StatusOK {
+		return errors.New("could not set share limits for torrents: %v unexpected status: %v", hashes, resp.StatusCode)
+	}
+
+	return nil
+}
+
+// SetTorrentUploadLimit set upload limit for torrent specified by hashes
+func (c *Client) SetTorrentUploadLimit(hashes []string, limit int64) error {
+	return c.SetTorrentUploadLimitCtx(context.Background(), hashes, limit)
+}
+
+// SetTorrentUploadLimitCtx set upload limit for torrent specified by hashes
+func (c *Client) SetTorrentUploadLimitCtx(ctx context.Context, hashes []string, limit int64) error {
+	opts := map[string]string{
+		"hashes": strings.Join(hashes, "|"),
+		"limit":  strconv.FormatInt(limit, 10),
+	}
+
+	resp, err := c.postCtx(ctx, "torrents/setUploadLimit", opts)
+	if err != nil {
+		return errors.Wrap(err, "could not set upload limit for torrents: %v", hashes)
+	}
+
+	defer resp.Body.Close()
+
+	if resp.StatusCode != http.StatusOK {
+		return errors.New("could not set upload limit for torrents: %v unexpected status: %v", hashes, resp.StatusCode)
 	}
 
 	return nil
